@@ -37,10 +37,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.9.98"
-
-/* For backwards compatibility */
-#include <gnutls/compat4.h>
+#define LIBGNUTLS_VERSION "0.9.99"
 
 #ifndef HAVE_SIZE_T
 # define HAVE_SIZE_T
@@ -64,8 +61,7 @@ extern "C" {
 
 typedef enum gnutls_cipher_algorithm { GNUTLS_CIPHER_NULL=1, 
 	GNUTLS_CIPHER_ARCFOUR_128, GNUTLS_CIPHER_3DES_CBC, GNUTLS_CIPHER_AES_128_CBC, 
-	GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_CIPHER_AES_256_CBC,
-	GNUTLS_CIPHER_ARCFOUR_40
+	GNUTLS_CIPHER_AES_256_CBC, GNUTLS_CIPHER_ARCFOUR_40
 } gnutls_cipher_algorithm;
 
 typedef enum gnutls_kx_algorithm { GNUTLS_KX_RSA=1, GNUTLS_KX_DHE_DSS, 
@@ -88,7 +84,7 @@ typedef enum gnutls_digest_algorithm { GNUTLS_DIG_NULL=1, GNUTLS_DIG_MD5,
 /* exported for other gnutls headers. This is the maximum number
  * of algorithms (ciphers, kx or macs). 
  */
-#define GNUTLS_MAX_ALGORITHM_NUM 10
+#define GNUTLS_MAX_ALGORITHM_NUM 16
 
 typedef enum gnutls_compression_method { GNUTLS_COMP_NULL=1, 
 	GNUTLS_COMP_ZLIB, 
@@ -180,6 +176,7 @@ typedef struct {
 	unsigned int size;
 } gnutls_datum;
 
+
 typedef struct {
 	const unsigned char * data;
 	unsigned int size;
@@ -251,12 +248,13 @@ size_t gnutls_record_check_pending(gnutls_session session);
 typedef enum gnutls_server_name_type { GNUTLS_NAME_DNS=1 
 } gnutls_server_name_type;
 
-int gnutls_get_server_name(gnutls_session session, void* data, int* data_length,
-				       int *type, int indx);
+int gnutls_server_name_set(gnutls_session session,
+	gnutls_server_name_type type,
+	const void *name, size_t name_length);
 
-int gnutls_set_server_name(gnutls_session session,
-			       gnutls_server_name_type type,
-			       const void *name, int name_length);
+int gnutls_server_name_get(gnutls_session session, 
+	void *data, size_t *data_length,
+	unsigned int * type, int unsigned indx);
 
 /* functions to set priority of cipher suites 
  */
@@ -284,11 +282,11 @@ const char *gnutls_protocol_get_name(gnutls_protocol_version version);
 
 /* get/set session 
  */
-int gnutls_session_set_data( gnutls_session session, const void* session_data, int session_data_size);
-int gnutls_session_get_data( gnutls_session session, void* session_data, int *session_data_size);
+int gnutls_session_set_data( gnutls_session session, const void* session_data, size_t session_data_size);
+int gnutls_session_get_data( gnutls_session session, void* session_data, size_t *session_data_size);
 /* returns the session ID */
 #define GNUTLS_MAX_SESSION_ID 32
-int gnutls_session_get_id( gnutls_session session, void* session_id, int *session_id_size);
+int gnutls_session_get_id( gnutls_session session, void* session_id, size_t *session_id_size);
 
 /* checks if this session is a resumed one 
  */
@@ -443,7 +441,7 @@ int gnutls_rsa_params_generate2(gnutls_rsa_params params, int bits);
 int gnutls_rsa_params_export_raw(gnutls_rsa_params params,
 	gnutls_datum * m, gnutls_datum *e,
 	gnutls_datum *d, gnutls_datum *p, gnutls_datum* q, 
-	gnutls_datum* u, int *bits);
+	gnutls_datum* u, unsigned int *bits);
 
 /* Session stuff
  */
@@ -475,7 +473,7 @@ void gnutls_openpgp_send_key(gnutls_session session, gnutls_openpgp_key_status s
  * Actually this function returns the hash of the given data.
  */
 int gnutls_fingerprint(gnutls_digest_algorithm algo, const gnutls_datum* data, 
-	unsigned char* result, int* result_size);
+	void* result, size_t* result_size);
 
 #ifndef GNUTLS_UI_H
 # define GNUTLS_UI_H
@@ -532,7 +530,7 @@ int gnutls_pkcs3_export_dh_params( const gnutls_datum * prime,
 
 /* get data from the session 
  */
-const gnutls_datum* gnutls_certificate_get_peers( gnutls_session, int* list_size);
+const gnutls_datum* gnutls_certificate_get_peers( gnutls_session, unsigned int* list_size);
 const gnutls_datum *gnutls_certificate_get_ours( gnutls_session session);
 
 time_t gnutls_certificate_activation_time_peers(gnutls_session session);
@@ -679,6 +677,7 @@ int gnutls_pem_base64_decode_alloc( const char* header, const gnutls_datum *b64_
 #define GNUTLS_E_INCOMPATIBLE_LIBTASN1_LIBRARY -203
 
 #define GNUTLS_E_OPENPGP_KEYRING_ERROR -204
+#define GNUTLS_E_X509_UNSUPPORTED_OID -205
 
 #define GNUTLS_E_UNIMPLEMENTED_FEATURE -1250
 
