@@ -136,7 +136,6 @@ static const gnutls_cipher_entry algorithms[] = {
 	{"3DES 168 CBC", GNUTLS_CIPHER_3DES_CBC, 8, 24, CIPHER_BLOCK, 8, 0 },
 	{"AES 128 CBC", GNUTLS_CIPHER_AES_128_CBC, 16, 16, CIPHER_BLOCK, 16, 0 },
 	{"AES 256 CBC", GNUTLS_CIPHER_AES_256_CBC, 16, 32, CIPHER_BLOCK, 16, 0 },
-	{"TWOFISH 128 CBC", GNUTLS_CIPHER_TWOFISH_128_CBC, 16, 16, CIPHER_BLOCK, 16, 0 },
 	{"ARCFOUR 128", GNUTLS_CIPHER_ARCFOUR_128, 1, 16, CIPHER_STREAM, 0, 0 },
 	{"ARCFOUR 40", GNUTLS_CIPHER_ARCFOUR_40, 1, 5, CIPHER_STREAM, 0, 1 },
 	{"RC2 40", GNUTLS_CIPHER_RC2_40_CBC, 8, 5, CIPHER_BLOCK, 8, 1 },
@@ -271,9 +270,6 @@ typedef struct {
  /* rfc3268: */
 #define GNUTLS_ANON_DH_AES_128_CBC_SHA { 0x00, 0x34 }
 #define GNUTLS_ANON_DH_AES_256_CBC_SHA { 0x00, 0x3A }
-/* gnutls private extensions: */
-#define GNUTLS_ANON_DH_TWOFISH_128_CBC_SHA { 0xFF, 0x50 } /* gnutls */
-
 
 /** SRP (not in TLS 1.0)
  ** draft-ietf-tls-srp-02:
@@ -304,22 +300,12 @@ typedef struct {
 #define GNUTLS_RSA_AES_128_CBC_SHA { 0x00, 0x2F }
 #define GNUTLS_RSA_AES_256_CBC_SHA { 0x00, 0x35 }
 
-/* gnutls private extensions: 
- */
-#define GNUTLS_RSA_TWOFISH_128_CBC_SHA { 0xFF, 0x51 } /* gnutls */
-
-
 /** DHE DSS 
  **/
 
 #define GNUTLS_DHE_DSS_3DES_EDE_CBC_SHA { 0x00, 0x13 }
 
 
-/* gnutls private extensions: 
- */
-#define GNUTLS_DHE_DSS_TWOFISH_128_CBC_SHA { 0xFF, 0x54 }
-
-
 /* draft-ietf-tls-openpgp-keys-04:
  */
 #define GNUTLS_DHE_DSS_3DES_EDE_CBC_RMD { 0x00, 0x72 }
@@ -347,10 +333,6 @@ typedef struct {
  **/
 #define GNUTLS_DHE_RSA_3DES_EDE_CBC_SHA { 0x00, 0x16 }
 
-/* gnutls private extensions: 
- */
-#define GNUTLS_DHE_RSA_TWOFISH_128_CBC_SHA { 0xFF, 0x55 } /* gnutls */
-
 /* rfc3268: 
  */
 #define GNUTLS_DHE_RSA_AES_128_CBC_SHA { 0x00, 0x33 }
@@ -372,10 +354,6 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_AES_256_CBC_SHA,
 				  GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_ANON_DH,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_TWOFISH_128_CBC_SHA,
-				  GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_KX_ANON_DH,
-				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
-
 	/* SRP */
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_3DES_EDE_CBC_SHA,
 				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_SRP,
@@ -415,9 +393,6 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_ARCFOUR_SHA,
 				  GNUTLS_CIPHER_ARCFOUR_128, GNUTLS_KX_DHE_DSS,
 				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_TWOFISH_128_CBC_SHA,
-				  GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_KX_DHE_DSS,
-				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_3DES_EDE_CBC_SHA,
 				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_DHE_DSS,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
@@ -437,9 +412,6 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 				  GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_DHE_DSS,
 				  GNUTLS_MAC_RMD160, GNUTLS_TLS1),
 	/* DHE_RSA */
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_TWOFISH_128_CBC_SHA,
-				  GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_KX_DHE_RSA,
-				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_3DES_EDE_CBC_SHA,
 				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_DHE_RSA,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
@@ -482,9 +454,6 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_AES_256_CBC_SHA,
 				  GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_RSA,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_TWOFISH_128_CBC_SHA,
-				  GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_KX_RSA,
-				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_3DES_EDE_CBC_RMD,
 				  GNUTLS_CIPHER_3DES_CBC,
 				  GNUTLS_KX_RSA, GNUTLS_MAC_RMD160, GNUTLS_TLS1),
