@@ -156,7 +156,7 @@ typedef struct {
 /* This is the maximum number of algorithms (ciphers or macs etc).
  * keep it synced with GNUTLS_MAX_ALGORITHM_NUM in gnutls.h
  */
-#define MAX_ALGOS 10
+#define MAX_ALGOS 16
 
 #define MAX_CIPHERSUITES 256
 
@@ -164,8 +164,7 @@ typedef struct {
 
 typedef enum gnutls_cipher_algorithm { GNUTLS_CIPHER_NULL=1, 
 	GNUTLS_CIPHER_ARCFOUR_128, GNUTLS_CIPHER_3DES_CBC, GNUTLS_CIPHER_AES_128_CBC, 
-	GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_CIPHER_AES_256_CBC,
-	GNUTLS_CIPHER_ARCFOUR_40, 
+	GNUTLS_CIPHER_AES_256_CBC, GNUTLS_CIPHER_ARCFOUR_40, 
 	
 	GNUTLS_CIPHER_RC2_40_CBC=90, GNUTLS_CIPHER_DES_CBC
 } gnutls_cipher_algorithm;
@@ -311,7 +310,7 @@ typedef enum gnutls_server_name_type { GNUTLS_NAME_DNS=1
 
 typedef struct {
    opaque name[MAX_SERVER_NAME_SIZE];
-   int name_length;
+   uint name_length;
    gnutls_server_name_type type;
 } server_name_st;
 
@@ -320,7 +319,7 @@ typedef struct {
 typedef struct {
 	server_name_st  server_names[MAX_SERVER_NAME_EXTENSIONS]; 
 	                /* limit server_name extensions */
-	int		server_names_size;
+	uint		server_names_size;
 	opaque 		srp_username[MAX_SRP_USERNAME];
 } TLSExtensions;
 
@@ -670,6 +669,6 @@ void _gnutls_set_adv_version( gnutls_session, gnutls_protocol_version);
 gnutls_protocol_version _gnutls_get_adv_version( gnutls_session);
 
 int gnutls_fingerprint(gnutls_digest_algorithm algo, const gnutls_datum* data, 
-	unsigned char* result, size_t* result_size);
+	void* result, size_t* result_size);
 
 #endif /* GNUTLS_INT_H */
