@@ -29,7 +29,7 @@ gnutls_free_function gnutls_free = free;
 gnutls_realloc_function gnutls_realloc = realloc;
 
 void* (*gnutls_calloc)(size_t, size_t) = calloc;
-char* (*gnutls_strdup)(const char*) = strdup;
+char* (*gnutls_strdup)(const char*) = _gnutls_strdup;
 
 int _gnutls_is_secure_mem_null( const void* ign) { return 0; }
 
