@@ -81,11 +81,12 @@ int kx_priority[PRI_MAX] =
 };
 int cipher_priority[PRI_MAX] =
     { GNUTLS_CIPHER_ARCFOUR_128, GNUTLS_CIPHER_AES_128_CBC,
-	GNUTLS_CIPHER_3DES_CBC,
+	GNUTLS_CIPHER_3DES_CBC, GNUTLS_CIPHER_AES_256_CBC,
 	GNUTLS_CIPHER_ARCFOUR_40, 0
 };
 int comp_priority[PRI_MAX] = { GNUTLS_COMP_ZLIB, GNUTLS_COMP_NULL, 0 };
-int mac_priority[PRI_MAX] = { GNUTLS_MAC_SHA, GNUTLS_MAC_MD5, 0 };
+int mac_priority[PRI_MAX] = 
+	{ GNUTLS_MAC_SHA, GNUTLS_MAC_MD5, GNUTLS_MAC_RMD160, 0 };
 int cert_type_priority[PRI_MAX] = { GNUTLS_CRT_X509, GNUTLS_CRT_OPENPGP, 0 };
 
 /* end of global stuff */
@@ -117,7 +118,8 @@ static int cert_callback(gnutls_session session,
 			 const gnutls_datum * req_ca_rdn, int nreqs)
 {
 	char issuer_dn[256];
-	int len, i, ret;
+	int i, ret;
+	size_t len;
 
 	/* Print the server's trusted CAs
 	 */
@@ -190,6 +192,8 @@ static gnutls_session init_tls_session(const char *hostname)
 			fprintf(stderr,
 				"Cannot set the maximum record size to %d.\n",
 				record_max_size);
+			fprintf(stderr,
+				"Possible values: 512, 1024, 2048, 4096.\n");
 			exit(1);
 		}
 	}
@@ -592,6 +596,9 @@ ssize_t socket_send(socket_st socket, const void *buffer, int buffer_size)
 			ret = send(socket.fd, buffer, buffer_size, 0);
 		} while (ret == -1 && errno == EINTR);
 
+	if (ret > 0 && ret != buffer_size && quiet)
+		fprintf(stderr,
+			"*** Only sent %d bytes instead of %d.\n", ret, buffer_size);
 
 	return ret;
 }
