@@ -105,9 +105,9 @@ char *x509_crlfile = NULL;
 #define RENEGOTIATE
 
 /* These are global */
-gnutls_srp_server_credentials srp_cred;
-gnutls_anon_server_credentials dh_cred;
-gnutls_certificate_credentials cert_cred;
+gnutls_srp_server_credentials srp_cred = NULL;
+gnutls_anon_server_credentials dh_cred = NULL;
+gnutls_certificate_credentials cert_cred = NULL;
 
 const int ssl_session_cache = 128;
 
@@ -295,8 +295,12 @@ gnutls_session initialize_session(void)
    gnutls_certificate_type_set_priority(session, cert_type_priority);
 
    gnutls_credentials_set(session, GNUTLS_CRD_ANON, dh_cred);
-   gnutls_credentials_set(session, GNUTLS_CRD_SRP, srp_cred);
-   gnutls_credentials_set(session, GNUTLS_CRD_CERTIFICATE, cert_cred);
+
+   if (srp_cred != NULL)
+      gnutls_credentials_set(session, GNUTLS_CRD_SRP, srp_cred);
+
+   if (cert_cred != NULL)
+      gnutls_credentials_set(session, GNUTLS_CRD_CERTIFICATE, cert_cred);
 
    gnutls_certificate_server_set_request(session, GNUTLS_CERT_REQUEST);
 
@@ -350,8 +354,8 @@ char *peer_print_info(gnutls_session session, int *ret_length,
     */
    {
       char dns[256];
-      int dns_size = sizeof(dns);
-      int type;
+      size_t dns_size = sizeof(dns);
+      unsigned int type;
 
       if (gnutls_server_name_get(session, dns, &dns_size, &type, 0) == 0) {
 	 sprintf(tmp2, "\n<p>Server Name: %s</p>\n", dns);
@@ -667,9 +671,9 @@ int main(int argc, char **argv)
     * Read README.crypt prior to using SRP.
     */
 #ifdef ENABLE_SRP
-   gnutls_srp_allocate_server_credentials(&srp_cred);
+   if (srp_passwd != NULL) {
+      gnutls_srp_allocate_server_credentials(&srp_cred);
 
-   if (srp_passwd != NULL)
       if ((ret =
 	   gnutls_srp_set_server_credentials_file(srp_cred, srp_passwd,
 						  srp_passwd_conf)) < 0) {
@@ -678,6 +682,7 @@ int main(int argc, char **argv)
 	 fprintf(stderr, "Error while setting SRP parameters\n");
 	 GERR(ret);
       }
+   }
 #endif
 
 #ifdef ENABLE_ANON
@@ -1028,10 +1033,10 @@ void serv_version(void)
 
 typedef struct {
    char session_id[SESSION_ID_SIZE];
-   int session_id_size;
+   unsigned int session_id_size;
 
    char session_data[SESSION_DATA_SIZE];
-   int session_data_size;
+   unsigned int session_data_size;
 } CACHE;
 
 static CACHE *cache_db;
@@ -1120,6 +1125,23 @@ static int wrap_db_delete(void *dbf, gnutls_datum key)
 
 }
 
+void print_serv_license(void)
+{
+	fprintf(stdout,
+		"\nCopyright (C) 2001-2003 Paul Sheer, Nikos Mavroyanopoulos\n"
+		"This program is free software; you can redistribute it and/or modify \n"
+		"it under the terms of the GNU General Public License as published by \n"
+		"the Free Software Foundation; either version 2 of the License, or \n"
+		"(at your option) any later version. \n" "\n"
+		"This program is distributed in the hope that it will be useful, \n"
+		"but WITHOUT ANY WARRANTY; without even the implied warranty of \n"
+		"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the \n"
+		"GNU General Public License for more details. \n" "\n"
+		"You should have received a copy of the GNU General Public License \n"
+		"along with this program; if not, write to the Free Software \n"
+		"Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.\n\n");
+}
+
 #ifdef HAVE_LIBOPENCDK
 
 static int
